You can subscribe to this list here.
| 2002 |
Jan
|
Feb
|
Mar
|
Apr
|
May
|
Jun
|
Jul
|
Aug
|
Sep
(1) |
Oct
(122) |
Nov
(152) |
Dec
(69) |
|---|---|---|---|---|---|---|---|---|---|---|---|---|
| 2003 |
Jan
(6) |
Feb
(25) |
Mar
(73) |
Apr
(82) |
May
(24) |
Jun
(25) |
Jul
(10) |
Aug
(11) |
Sep
(10) |
Oct
(54) |
Nov
(203) |
Dec
(182) |
| 2004 |
Jan
(307) |
Feb
(305) |
Mar
(430) |
Apr
(312) |
May
(187) |
Jun
(342) |
Jul
(487) |
Aug
(637) |
Sep
(336) |
Oct
(373) |
Nov
(441) |
Dec
(210) |
| 2005 |
Jan
(385) |
Feb
(480) |
Mar
(636) |
Apr
(544) |
May
(679) |
Jun
(625) |
Jul
(810) |
Aug
(838) |
Sep
(634) |
Oct
(521) |
Nov
(965) |
Dec
(543) |
| 2006 |
Jan
(494) |
Feb
(431) |
Mar
(546) |
Apr
(411) |
May
(406) |
Jun
(322) |
Jul
(256) |
Aug
(401) |
Sep
(345) |
Oct
(542) |
Nov
(308) |
Dec
(481) |
| 2007 |
Jan
(427) |
Feb
(326) |
Mar
(367) |
Apr
(255) |
May
(244) |
Jun
(204) |
Jul
(223) |
Aug
(231) |
Sep
(354) |
Oct
(374) |
Nov
(497) |
Dec
(362) |
| 2008 |
Jan
(322) |
Feb
(482) |
Mar
(658) |
Apr
(422) |
May
(476) |
Jun
(396) |
Jul
(455) |
Aug
(267) |
Sep
(280) |
Oct
(253) |
Nov
(232) |
Dec
(304) |
| 2009 |
Jan
(486) |
Feb
(470) |
Mar
(458) |
Apr
(423) |
May
(696) |
Jun
(461) |
Jul
(551) |
Aug
(575) |
Sep
(134) |
Oct
(110) |
Nov
(157) |
Dec
(102) |
| 2010 |
Jan
(226) |
Feb
(86) |
Mar
(147) |
Apr
(117) |
May
(107) |
Jun
(203) |
Jul
(193) |
Aug
(238) |
Sep
(300) |
Oct
(246) |
Nov
(23) |
Dec
(75) |
| 2011 |
Jan
(133) |
Feb
(195) |
Mar
(315) |
Apr
(200) |
May
(267) |
Jun
(293) |
Jul
(353) |
Aug
(237) |
Sep
(278) |
Oct
(611) |
Nov
(274) |
Dec
(260) |
| 2012 |
Jan
(303) |
Feb
(391) |
Mar
(417) |
Apr
(441) |
May
(488) |
Jun
(655) |
Jul
(590) |
Aug
(610) |
Sep
(526) |
Oct
(478) |
Nov
(359) |
Dec
(372) |
| 2013 |
Jan
(467) |
Feb
(226) |
Mar
(391) |
Apr
(281) |
May
(299) |
Jun
(252) |
Jul
(311) |
Aug
(352) |
Sep
(481) |
Oct
(571) |
Nov
(222) |
Dec
(231) |
| 2014 |
Jan
(185) |
Feb
(329) |
Mar
(245) |
Apr
(238) |
May
(281) |
Jun
(399) |
Jul
(382) |
Aug
(500) |
Sep
(579) |
Oct
(435) |
Nov
(487) |
Dec
(256) |
| 2015 |
Jan
(338) |
Feb
(357) |
Mar
(330) |
Apr
(294) |
May
(191) |
Jun
(108) |
Jul
(142) |
Aug
(261) |
Sep
(190) |
Oct
(54) |
Nov
(83) |
Dec
(22) |
| 2016 |
Jan
(49) |
Feb
(89) |
Mar
(33) |
Apr
(50) |
May
(27) |
Jun
(34) |
Jul
(53) |
Aug
(53) |
Sep
(98) |
Oct
(206) |
Nov
(93) |
Dec
(53) |
| 2017 |
Jan
(65) |
Feb
(82) |
Mar
(102) |
Apr
(86) |
May
(187) |
Jun
(67) |
Jul
(23) |
Aug
(93) |
Sep
(65) |
Oct
(45) |
Nov
(35) |
Dec
(17) |
| 2018 |
Jan
(26) |
Feb
(35) |
Mar
(38) |
Apr
(32) |
May
(8) |
Jun
(43) |
Jul
(27) |
Aug
(30) |
Sep
(43) |
Oct
(42) |
Nov
(38) |
Dec
(67) |
| 2019 |
Jan
(32) |
Feb
(37) |
Mar
(53) |
Apr
(64) |
May
(49) |
Jun
(18) |
Jul
(14) |
Aug
(53) |
Sep
(25) |
Oct
(30) |
Nov
(49) |
Dec
(31) |
| 2020 |
Jan
(87) |
Feb
(45) |
Mar
(37) |
Apr
(51) |
May
(99) |
Jun
(36) |
Jul
(11) |
Aug
(14) |
Sep
(20) |
Oct
(24) |
Nov
(40) |
Dec
(23) |
| 2021 |
Jan
(14) |
Feb
(53) |
Mar
(85) |
Apr
(15) |
May
(19) |
Jun
(3) |
Jul
(14) |
Aug
(1) |
Sep
(57) |
Oct
(73) |
Nov
(56) |
Dec
(22) |
| 2022 |
Jan
(3) |
Feb
(22) |
Mar
(6) |
Apr
(55) |
May
(46) |
Jun
(39) |
Jul
(15) |
Aug
(9) |
Sep
(11) |
Oct
(34) |
Nov
(20) |
Dec
(36) |
| 2023 |
Jan
(79) |
Feb
(41) |
Mar
(99) |
Apr
(169) |
May
(48) |
Jun
(16) |
Jul
(16) |
Aug
(57) |
Sep
(19) |
Oct
|
Nov
|
Dec
|
| S | M | T | W | T | F | S |
|---|---|---|---|---|---|---|
|
|
|
|
1
|
2
|
3
|
4
|
|
5
|
6
|
7
(2) |
8
(16) |
9
|
10
|
11
(1) |
|
12
(19) |
13
(12) |
14
(15) |
15
(5) |
16
(15) |
17
(1) |
18
(15) |
|
19
|
20
(3) |
21
(1) |
22
(12) |
23
(4) |
24
(5) |
25
(15) |
|
26
(4) |
27
(12) |
28
|
29
(2) |
30
(13) |
31
(13) |
|
|
From: <sv...@va...> - 2014-01-07 22:28:09
|
Author: tom
Date: Tue Jan 7 22:27:57 2014
New Revision: 13768
Log:
The value of AT_BASE should be the offset between where the ELF interpreter
expected to be loaded (as expressed in the ELF headers) and where it was
actually loaded, and not (as valgrind was doing) the absolute value of the
load address for the interpreter.
Note that when prelink is not in use the two are normally the same, as the
intpreter (like all shared libraries) is normally linked with a zero load
address. When prelinked that is no longer true.
With that fixed, the hack to patch out AT_BASE to avoid confusing gdb on
systems where prelink is in use is no longer needed.
Fixes BZ#329612
Modified:
trunk/NEWS
trunk/coregrind/m_initimg/initimg-linux.c
trunk/coregrind/m_ume/elf.c
trunk/coregrind/pub_core_ume.h
Modified: trunk/NEWS
==============================================================================
--- trunk/NEWS (original)
+++ trunk/NEWS Tue Jan 7 22:27:57 2014
@@ -40,6 +40,7 @@
328205 Implement additional Xen hypercalls
328455 s390x: SIGILL after emitting wrong register pair for ldxbr
328711 valgrind.1 manpage "memcheck options" section is badly generated
+329612 Incorrect handling of AT_BASE for image execution
Release 3.9.0 (31 October 2013)
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
Modified: trunk/coregrind/m_initimg/initimg-linux.c
==============================================================================
--- trunk/coregrind/m_initimg/initimg-linux.c (original)
+++ trunk/coregrind/m_initimg/initimg-linux.c Tue Jan 7 22:27:57 2014
@@ -664,19 +664,7 @@
break;
case AT_BASE:
- /* When gdbserver sends the auxv to gdb, the AT_BASE has
- to be ignored, as otherwise gdb adds this offset
- to loaded shared libs, causing wrong address
- relocation e.g. when inserting breaks.
- However, ignoring AT_BASE makes V crash on Android 4.1.
- So, keep the AT_BASE on android for now.
- ??? Need to dig in depth about AT_BASE/GDB interaction */
-# if !defined(VGPV_arm_linux_android) \
- && !defined(VGPV_x86_linux_android) \
- && !defined(VGPV_mips32_linux_android)
- auxv->a_type = AT_IGNORE;
-# endif
- auxv->u.a_val = info->interp_base;
+ auxv->u.a_val = info->interp_offset;
break;
case AT_PLATFORM:
Modified: trunk/coregrind/m_ume/elf.c
==============================================================================
--- trunk/coregrind/m_ume/elf.c (original)
+++ trunk/coregrind/m_ume/elf.c Tue Jan 7 22:27:57 2014
@@ -310,11 +310,6 @@
void *entry;
ESZ(Addr) ebase = 0;
- /* The difference between where the interpreter got mapped and
- where it asked to be mapped. Needed for computing the ppc64 ELF
- entry point and initial tocptr (R2) value. */
- ESZ(Word) interp_offset = 0;
-
# if defined(HAVE_PIE)
ebase = info->exe_base;
# endif
@@ -500,8 +495,7 @@
VG_(close)(interp->fd);
entry = (void *)(advised - interp_addr + interp->e.e_entry);
- info->interp_base = (ESZ(Addr))advised;
- interp_offset = advised - interp_addr;
+ info->interp_offset = advised - interp_addr;
VG_(free)(interp->p);
VG_(free)(interp);
@@ -518,12 +512,11 @@
is the static chain value. */
info->init_ip = ((ULong*)entry)[0];
info->init_toc = ((ULong*)entry)[1];
- info->init_ip += interp_offset;
- info->init_toc += interp_offset;
+ info->init_ip += info->interp_offset;
+ info->init_toc += info->interp_offset;
#else
info->init_ip = (Addr)entry;
info->init_toc = 0; /* meaningless on this platform */
- (void) interp_offset; /* stop gcc complaining it is unused */
#endif
VG_(free)(e->p);
VG_(free)(e);
Modified: trunk/coregrind/pub_core_ume.h
==============================================================================
--- trunk/coregrind/pub_core_ume.h (original)
+++ trunk/coregrind/pub_core_ume.h Tue Jan 7 22:27:57 2014
@@ -52,10 +52,10 @@
Addr exe_end; // INOUT: highest (allowed) address
#if !defined(VGO_darwin)
- Addr phdr; // OUT: address phdr was mapped at
- Int phnum; // OUT: number of phdrs
- UInt stack_prot; // OUT: stack permissions
- Addr interp_base; // OUT: where interpreter (ld.so) was mapped
+ Addr phdr; // OUT: address phdr was mapped at
+ Int phnum; // OUT: number of phdrs
+ UInt stack_prot; // OUT: stack permissions
+ PtrdiffT interp_offset; // OUT: relocation offset for ld.so
#else
Addr stack_start; // OUT: address of start of stack segment (hot)
Addr stack_end; // OUT: address of end of stack segment (cold)
|
|
From: Sasikanth b. <sas...@gm...> - 2014-01-07 08:59:13
|
Hi Petar,
With the latest patches in-review from Dr. Zahid Anwar, I'm able
to run valgrind on mips/octeon but I'm not getting
proper trace.
configure options: ./configure --host=mips64-target-linux-gnu
--build=x86_64-crosscompile-linux-gnu
is there anything I'm missing?
root@sasi:/root> valgrind ./a.out 1
==4236== Memcheck, a memory error detector
==4236== Copyright (C) 2002-2013, and GNU GPL'd, by Julian Seward et al.
==4236== Using Valgrind-3.10.0.SVN and LibVEX; rerun with -h for copyright info
==4236== Command: ./a.out 1
==4236==
==4236== Conditional jump or move depends on uninitialised value(s)
==4236== at 0x401AD20: ??? (in /lib64/ld-2.11.1.so)
==4236== by 0x4008EA0: ??? (in /lib64/ld-2.11.1.so)
==4236==
==4236== Conditional jump or move depends on uninitialised value(s)
==4236== at 0x401AEB0: ??? (in /lib64/ld-2.11.1.so)
==4236== by 0x4006204: ??? (in /lib64/ld-2.11.1.so)
==4236==
==4236== Conditional jump or move depends on uninitialised value(s)
==4236== at 0x401AEB0: ??? (in /lib64/ld-2.11.1.so)
==4236== by 0x400C7BC: ??? (in /lib64/ld-2.11.1.so)
==4236==
4236:
==4236== Invalid read of size 4
==4236== at 0x400D148: ??? (in /lib64/ld-2.11.1.so)
==4236== by 0x4004B4C: ??? (in /lib64/ld-2.11.1.so)
==4236== Address 0x50 is not stack'd, malloc'd or (recently) free'd
==4236==
==4236==
==4236== Process terminating with default action of signal 11 (SIGSEGV)
==4236== Access not within mapped region at address 0x50
==4236== at 0x400D148: ??? (in /lib64/ld-2.11.1.so)
==4236== by 0x4004B4C: ??? (in /lib64/ld-2.11.1.so)
==4236== If you believe this happened as a result of a stack
==4236== overflow in your program's main thread (unlikely but
==4236== possible), you can try to increase the size of the
==4236== main thread stack using the --main-stacksize= flag.
==4236== The main thread stack size used in this run was 8388608.
==4236== Jump to the invalid address stated on the next line
==4236== at 0x9E0: ???
==4236== by 0x40338F0: _vgnU_freeres (vg_preloaded.c:63)
==4236== by 0x4004B50: ??? (in /lib64/ld-2.11.1.so)
==4236== Address 0x9e0 is not stack'd, malloc'd or (recently) free'd
==4236==
==4236==
==4236== Process terminating with default action of signal 11 (SIGSEGV)
==4236== Bad permissions for mapped region at address 0x9E0
==4236== at 0x9E0: ???
==4236== by 0x40338F0: _vgnU_freeres (vg_preloaded.c:63)
==4236== by 0x4004B50: ??? (in /lib64/ld-2.11.1.so)
==4236==
==4236== HEAP SUMMARY:
==4236== in use at exit: 0 bytes in 0 blocks
==4236== total heap usage: 0 allocs, 0 frees, 0 bytes allocated
==4236==
==4236== All heap blocks were freed -- no leaks are possible
==4236==
==4236== For counts of detected and suppressed errors, rerun with: -v
==4236== Use --track-origins=yes to see where uninitialised values come from
==4236== ERROR SUMMARY: 5 errors from 5 contexts (suppressed: 0 from 0)
Segmentation fault
Thanks
Sasi
On Sun, Nov 17, 2013 at 10:33 AM, Petar Jovanovic <mip...@gm...> wrote:
> Hello Sasi,
>
> From what I can see, you have come across 'ldx' instruction that comes from
> MIPS64 DSP ASE that is not yet supported in Valgrind. There are instructions
> missing from Cavium set, so if your program is built with Cavium flags it is
> likely that you will come across more unimplemented instructions even if you
> workaround this one.
>
> There are a few patches in-review that you may want to cherry pick and try,
> they also include support for 'ldx' instruction, see:
>
> https://bugs.kde.org/show_bug.cgi?id=326444
> https://bugs.kde.org/show_bug.cgi?id=327223
>
> Cheers,
> Petar
>
>
> On Wed, Nov 13, 2013 at 5:23 PM, Sasikanth babu <sas...@gm...>
> wrote:
>>
>> Hi all,
>>
>> I'm using valgrind 3.9.0 which has the mips octeon support but when I
>> tried
>> run valgrind on octeon, it thows an error saying unhandled instruction
>> bytes.
>>
>>
>> root@octeon-test:/root> valgrind /bin/ls
>> ==1631== Memcheck, a memory error detector
>> ==1631== Copyright (C) 2002-2013, and GNU GPL'd, by Julian Seward et al.
>> ==1631== Using Valgrind-3.9.0 and LibVEX; rerun with -h for copyright info
>> ==1631== Command: /bin/ls
>> ==1631==
>> Error occured while trying to decode MIPS32 DSP instruction.
>> Your platform probably doesn't support MIPS32 DSP ASE.
>> vex mips->IR: unhandled instruction bytes: 0x7C 0x65 0x1A 0xA
>> ==1631== valgrind: Unrecognised instruction at address 0x40190dc.
>>
>> I see that the support was added only for OCTEON_CN63XX and I'm using
>> is OCTEON_CN68XX. Any pointers on how to solve this issue,
>>
>> Thanks in Advance
>> Sasi
>>
>>
>> ------------------------------------------------------------------------------
>> DreamFactory - Open Source REST & JSON Services for HTML5 & Native Apps
>> OAuth, Users, Roles, SQL, NoSQL, BLOB Storage and External API Access
>> Free app hosting. Or install the open source package on any LAMP server.
>> Sign up and see examples for AngularJS, jQuery, Sencha Touch and Native!
>>
>> http://pubads.g.doubleclick.net/gampad/clk?id=63469471&iu=/4140/ostg.clktrk
>> _______________________________________________
>> Valgrind-developers mailing list
>> Val...@li...
>> https://lists.sourceforge.net/lists/listinfo/valgrind-developers
>
>
|